# -*- coding: UTF-8 -*-
from setuphelpers import *
import json
import requests


def update_package():
    # Declaring local variables
    package_updated = False
    proxies = get_proxies()
    if not proxies:
        proxies = get_proxies_from_wapt_console()
    app_name = control.name
    arch_dict = {"x64": "win64", "x86": "win", "all": "win"}
    lang = control.locale

    # Translating locale
    if "en" in lang:
        lang = "en-US"
    if "es" in lang:
        lang = "es-ES"

    # Getting latest version from official sources
    download_url = requests.head(
        "https://download.mozilla.org/?product=firefox-esr-latest-ssl&os=%s&lang=%s" % (arch_dict[control.architecture], lang), proxies=proxies
    ).headers["Location"]
    latest_bin = download_url.rsplit("/", 1)[1].replace("%20", "_")
    version = latest_bin.split("_")[-1].split("esr")[0]
    version_from_api = (
        json.loads(wgets("https://product-details.mozilla.org/1.0/firefox_versions.json", proxies=proxies))
        .get("FIREFOX_ESR_NEXT", "0")
        .replace("esr", "")
    )
    if Version(version_from_api) > version:
        download_url = download_url.replace(version, version_from_api)
        version = version_from_api
        latest_bin = download_url.rsplit("/", 1)[1].replace("%20", "_")

    # Downloading latest binaries
    print("Latest %s version is: %s" % (app_name, version))
    print("Download download_url is: %s" % download_url)
    if not isfile(latest_bin):
        print("Downloading: %s" % latest_bin)
        wget(download_url, latest_bin, proxies=proxies)
    else:
        print("Binary is present: %s" % latest_bin)

    # Changing version of the package
    if Version(version) > Version(control.get_software_version()):
        print("Software version updated (from: %s to: %s)" % (control.get_software_version(), Version(version)))
        package_updated = True
    else:
        print("Software version up-to-date (%s)" % Version(version))
    control.set_software_version(version)
    control.save_control_to_wapt()

    # Deleting outdated binaries
    remove_outdated_binaries(version)

    # Validating or not update-package-sources
    return package_updated
